CiphertextAlt

Struct CiphertextAlt 

pub struct CiphertextAlt<E: Pairing> {
    pub X_r: E::G1Affine,
    pub enc_chunks: Vec<E::G1Affine>,
    pub commitment: E::G1Affine,
    pub X_r_sum: E::G1Affine,
}
Ciphertext used with LegoGroth16 and the slightly modified SAVER protocol. See saver_legogroth16::protocol_2 for more details.

Fields

X_r: E::G1Affineenc_chunks: Vec<E::G1Affine>commitment: E::G1AffineX_r_sum: E::G1Affine

Implementations

Source

impl<E: Pairing> CiphertextAlt<E>

pub fn decrypt( &self, sk: &SecretKey<E::ScalarField>, dk: impl Into<PreparedDecryptionKey<E>>, g_i: &[E::G1Affine], chunk_bit_size: u8, ) -> Result<(E::ScalarField, E::G1Affine)>

Decrypt this ciphertext returning the plaintext and commitment to randomness

pub fn decrypt_given_pairing_powers( &self, sk: &SecretKey<E::ScalarField>, dk: impl Into<PreparedDecryptionKey<E>>, g_i: &[E::G1Affine], chunk_bit_size: u8, pairing_powers: &[Vec<PairingOutput<E>>], ) -> Result<(E::ScalarField, E::G1Affine)>

Same as Self::decrypt but takes pairing powers (see PreparedDecryptionKey::pairing_powers) that can be precomputed for faster decryption

pub fn verify_commitment( &self, ek: impl Into<PreparedEncryptionKey<E>>, gens: impl Into<PreparedEncryptionGens<E>>, ) -> Result<()>

Verify that the ciphertext correctly commits to the message

pub fn verify_decryption( &self, message: &E::ScalarField, nu: &E::G1Affine, chunk_bit_size: u8, dk: impl Into<PreparedDecryptionKey<E>>, g_i: &[E::G1Affine], gens: impl Into<PreparedEncryptionGens<E>>, ) -> Result<()>

Verify that the decrypted message corresponds to original plaintext in the ciphertext

pub fn verify_decryption_with_randomized_pairing_checker( &self, message: &E::ScalarField, nu: &E::G1Affine, chunk_bit_size: u8, dk: impl Into<PreparedDecryptionKey<E>>, g_i: &[E::G1Affine], gens: impl Into<PreparedEncryptionGens<E>>, pairing_checker: &mut RandomizedPairingChecker<E>, ) -> Result<()>

Verify that the decrypted message corresponds to original plaintext in the ciphertext but using randomized pairing checker

pub fn decrypt_given_legogroth16_vk( &self, sk: &SecretKey<E::ScalarField>, dk: impl Into<PreparedDecryptionKey<E>>, snark_vk: &VerifyingKey<E>, chunk_bit_size: u8, ) -> Result<(E::ScalarField, E::G1Affine)>

pub fn verify_decryption_given_legogroth16_vk( &self, message: &E::ScalarField, chunk_bit_size: u8, nu: &E::G1Affine, dk: impl Into<PreparedDecryptionKey<E>>, snark_vk: &VerifyingKey<E>, gens: impl Into<PreparedEncryptionGens<E>>, ) -> Result<()>